@@ -19,7 +19,12 @@ import os
 import inspect
 
 from pkg_resources import Requirement
-from portage import portage_exception
+try:
+    #portage >=2.2
+    from portage import exception as portage_exception
+except ImportError:
+    #portage <2.2
+    from portage import portage_exception
 
 from yolk.pypi import CheeseShop
 from yolk.yolklib import get_highest_version
@@ -31,7 +36,7 @@ from g_pypi.__init__ import __version__ as VERSION
 
 
 __docformat__ = 'restructuredtext'
-__revision__ = '$Revision: 203 $'[11:-1].strip()
+__revision__ = '$Revision: 209 $'[11:-1].strip()
 
 
 
