@@ -49,7 +49,20 @@ such as PN, PV, MY_P, SRC_URI
 import urlparse
 import re
 
-from portage import pkgsplit, portage_dep, portage_exception
+from portage import pkgsplit
+try:
+    #portage >=2.2
+    from portage import dep as portage_dep
+except ImportError:
+    #portage <=2.1
+    from portage import portage_dep
+
+try:
+    #portage >=2.2
+    from portage import exception as portage_exception
+except ImportError:
+    #portage <=2.1
+    from portage import portage_exception
 
 __docformat__ = 'restructuredtext'
 
