@@ -17,6 +17,14 @@ import logging
 #import fnmatch
 
 import portage
+
+try:
+    #portage >= 2.2
+    from portage import dep as portage_dep
+except ImportError:
+    #portage <= 2.1
+    from portage import portage_dep
+
 sys.path.insert(0, "/usr/lib/gentoolkit/pym")
 import gentoolkit
 
@@ -56,7 +64,7 @@ def valid_cpn(cpn):
 
     @returns: True if installed, False if not installed
     """
-    if portage.portage_dep.isvalidatom(cpn):
+    if portage_dep.isvalidatom(cpn):
         return True
     else:
         return False
@@ -107,7 +115,7 @@ def unpack_ebuild(ebuild_path):
     @returns: None if succeed, raises OSError if fails to unpack
 
     """
-    (status, output) = commands.getstatusoutput("ebuild %s clean digest setup clean unpack" % ebuild_path)
+    (status, output) = commands.getstatusoutput("ebuild %s digest setup clean unpack" % ebuild_path)
     if status:
         #Portage's error message, sometimes.
         #Couldn't determine PN or PV so we misnamed ebuild
